

.. _sphx_glr_auto_examples_plot_tot_histogram.py:


==================
ToT histogram.
==================

This example shows how to create a simple histogram of the PMT signals.




.. image:: /auto_examples/images/sphx_glr_plot_tot_histogram_001.png
    :align: center





.. code-block:: python


    import pandas as pd
    import matplotlib.pyplot as plt
    import km3pipe.style
    km3pipe.style.use('default')


    filename = "data/km3net_jul13_90m_muatm50T655.km3_v5r1.JTE_r2356.root.0-499.h5"

    hits = pd.read_hdf(filename, 'hits')
    hits.hist("tot", bins=254, log=True, edgecolor='none')
    plt.title("ToT distribution")
    plt.xlabel("ToT [ns]")

**Total running time of the script:**
(0 minutes 0.725 seconds)



.. container:: sphx-glr-download

    **Download Python source code:** :download:`plot_tot_histogram.py <plot_tot_histogram.py>`


.. container:: sphx-glr-download

    **Download IPython notebook:** :download:`plot_tot_histogram.ipynb <plot_tot_histogram.ipynb>`

.. rst-class:: sphx-glr-signature

    `Generated by Sphinx-Gallery <http://sphinx-gallery.readthedocs.io>`_
